==> haskell-attoparsec-0.13.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.1.0
id: attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf
key: attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
abi: 9923dfc232f308b08fefaf172c27013b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-0.13.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-0.13.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/attoparsec-0.13.1.0
hs-libraries: HSattoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.1.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.1.0
id: attoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a
key: attoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
abi: bae3fb55c452ac5ff866cab9c5e6db63
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-0.13.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/attoparsec-0.13.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/attoparsec-0.13.1.0
hs-libraries: HSattoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 scientific-0.3.4.13-4xwcJxzSIhZ6kELOWf7cDt
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
